@@ -1253,17 +1253,15 @@ class _():
           "Improper set of PDB SCALE records%s" % source_info)
     return self._scale_matrix
 
-  def process_BIOMT_records(self,error_handle=True,eps=1e-4):
+  def process_BIOMT_records(self):
     import iotbx.mtrix_biomt
-    return iotbx.mtrix_biomt.process_BIOMT_records(
-      lines = self.extract_remark_iii_records(350),
-      eps=eps)
+    return iotbx.mtrix_biomt.process_BIOMT_records_pdb(
+      lines = self.extract_remark_iii_records(350))
 
-  def process_MTRIX_records(self, eps=1e-4):
+  def process_MTRIX_records(self):
     import iotbx.mtrix_biomt
-    return iotbx.mtrix_biomt.process_MTRIX_records(
-      lines=self.crystallographic_section(),
-      eps=eps)
+    return iotbx.mtrix_biomt.process_MTRIX_records_pdb(
+      lines=self.crystallographic_section())
 
   def get_r_rfree_sigma(self, file_name=None):
     from iotbx.pdb import extract_rfactors_resolutions_sigma
